#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pretty-hex
version:              1.1
visibility:           public
id:                   pretty-hex-1.1-2i4ClvFN4Y7LxbHQYNmVC0
key:                  pretty-hex-1.1-2i4ClvFN4Y7LxbHQYNmVC0
license:              BSD-3-Clause
maintainer:           Eric Mertens <emertens@galois.com>
synopsis:             A library for hex dumps of ByteStrings
description:
    This library generates pretty hex dumps of ByteStrings in the
    style of other common *nix hex dump tools.

category:             Data
abi:                  f7456e84bae1d4bfd05369a4cf28be96
exposed:              True
exposed-modules:      Hexdump
import-dirs:          /usr/lib/ghc-8.10.5/site-local/pretty-hex-1.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/pretty-hex-1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/pretty-hex-1.1
hs-libraries:         HSpretty-hex-1.1-2i4ClvFN4Y7LxbHQYNmVC0
depends:              base-4.14.2.0 bytestring-0.10.12.0
haddock-interfaces:   /usr/share/doc/haskell-pretty-hex/html/pretty-hex.haddock
haddock-html:         /usr/share/doc/haskell-pretty-hex/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

